# Generated by roxygen2: do not edit by hand

S3method(AIC,tslm)
S3method(BIC,tslm)
S3method(anova,tslm)
S3method(coef,tslm)
S3method(crossFactors,default)
S3method(crossFactors,formula)
S3method(eovcheck,formula)
S3method(eovcheck,lm)
S3method(fitted,tslm)
S3method(formula,tslm)
S3method(interactionPlots,default)
S3method(interactionPlots,formula)
S3method(logLik,tslm)
S3method(model.frame,tslm)
S3method(modelcheck,lm)
S3method(nobs,tslm)
S3method(normcheck,default)
S3method(normcheck,lm)
S3method(normcheck,tslm)
S3method(onewayPlot,default)
S3method(onewayPlot,formula)
S3method(onewayPlot,lm)
S3method(plot,tslm)
S3method(predict,tslm)
S3method(print,anova.tslm)
S3method(print,s20xModelcheck_ggplot2)
S3method(print,s20xNormcheck_ggplot2)
S3method(print,summary.tslm)
S3method(print,tslm)
S3method(residuals,tslm)
S3method(summary,tslm)
S3method(summaryStats,default)
S3method(summaryStats,formula)
S3method(summaryStats,matrix)
S3method(trendscatter,default)
S3method(trendscatter,formula)
S3method(vcov,tslm)
export(autocorPlot)
export(casestudy)
export(ciReg)
export(cooks20x)
export(crossFactors)
export(crosstabs)
export(cs)
export(displayPairs)
export(eovcheck)
export(estimateContrasts)
export(freq1way)
export(getVersion)
export(interactionPlots)
export(layout20x)
export(lcs)
export(levene.test)
export(listCS)
export(listCaseStudies)
export(modelcheck)
export(multipleComp)
export(normcheck)
export(ocs)
export(onewayPlot)
export(openCaseStudy)
export(opencs)
export(pairs20x)
export(predict20x)
export(predictCount)
export(predictGLM)
export(residPlot)
export(rowdistr)
export(rr)
export(skewness)
export(summary1way)
export(summary2way)
export(summaryStats)
export(trendscatter)
export(tslm)
export(twosampPlot)
import(graphics)
import(stats)
importFrom(GGally,eval_data_col)
importFrom(GGally,ggpairs)
importFrom(ggplot2,aes)
importFrom(ggplot2,after_stat)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_blank)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_size_identity)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_void)
importFrom(grDevices,colors)
importFrom(grDevices,nclass.Sturges)
importFrom(graphics,abline)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(grid,unit)
importFrom(grid,viewport)
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(nlme,corARMA)
importFrom(nlme,gls)
importFrom(rlang,.data)
importFrom(rlang,get_expr)
importFrom(rmarkdown,render)
importFrom(rstudioapi,isAvailable)
importFrom(rstudioapi,navigateToFile)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,acf)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,family)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,nobs)
importFrom(stats,predict)
importFrom(stats,predict.glm)
importFrom(stats,predict.lm)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,qt)
importFrom(stats,residuals)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(tools,file_path_sans_ext)
importFrom(utils,browseURL)
importFrom(utils,file.edit)
importFrom(utils,packageDescription)
importFrom(utils,packageVersion)
importFrom(utils,read.table)
importFrom(utils,vignette)
