data (butterfat.df)
interactionPlots(Butterfat~Breed+Age,data=butterfat.df)
butterfat.fit<-lm(Butterfat~Breed+Age+Breed*Age,data=butterfat.df)
eovcheck(butterfat.fit)
summary2way(butterfat.fit,page="table")
butterfat.fit1<-lm(Butterfat~Breed+Age,data=butterfat.df)
summary2way(butterfat.fit1,page="table")
butterfat.fit2<-lm(Butterfat~Breed,data=butterfat.df)
eovcheck(butterfat.fit2)
butterfat.fit3<-lm(log(Butterfat)~Breed,data=butterfat.df)
eovcheck(butterfat.fit3)
normcheck(butterfat.fit3)
summary1way(butterfat.fit3)
multipleComp(butterfat.fit3)

