data (camplake.df)
pairs20x(camplake.df[c(3,1:2)])
bluegill.fit<-lm(Length~Age+Scale.Radius,data=camplake.df)
eovcheck(bluegill.fit)
bluegill.fit1<-lm(log(Length)~Age+Scale.Radius,data=camplake.df)
eovcheck(bluegill.fit1)
plot(bluegill.fit1,which=1)
layout20x(1,2)
plot(residuals(bluegill.fit1)~Age,main="Residual plot (Age)",data=camplake.df)
plot(residuals(bluegill.fit1)~Scale.Radius,main="Residual plot (Scale Radius)",data=camplake.df)
layout20x(1,1)
bluegill.fit2<-lm(log(Length)~Age+I(Age^2)+ Scale.Radius,data=camplake.df)
summary(bluegill.fit2)
plot(bluegill.fit2,which=1)
normcheck(bluegill.fit2)
cooks20x(bluegill.fit2)
exp(ciReg(bluegill.fit2))

