data (apples.df)
boxplot(Weight~Rootstock,main="Apple tree weight by rootstock",ylab="weight",xlab="rootstock",data=apples.df)
summaryStats(Weight~Rootstock,data=apples.df)
boxplot(Weight~Propagated,main="Apple tree weight by propagation",ylab="weight",xlab="propagation",data=apples.df)
summaryStats(Weight~Propagated,data=apples.df)
propagation.fit<-lm(Weight~Propagated,data=apples.df)
eovcheck(propagation.fit)
normcheck(propagation.fit)
summary(propagation.fit)
ciReg(propagation.fit)
summary1way(propagation.fit)
multipleComp(propagation.fit)
t.test(Weight~Propagated,data=apples.df,var.equal=T)

