data (technitron.df)
technitron.df
pairs(technitron.df[c(1:4,6:8)])
pairs20x(technitron.df[c(1:4,8)])
technitron.df<-within(technitron.df,{dept1.<-factor(dept)})
tech.fit<-lm(salary~yrs.empl+prior.yrs+educ+gender+ super+dept1.,data=technitron.df)
eovcheck(tech.fit)
tech.fit1<-lm(log(salary)~yrs.empl+prior.yrs+educ+ gender+super+dept1.,data=technitron.df)
plot(tech.fit1,which=1)
summary(tech.fit1)
tech.fit2<-lm(log(salary)~yrs.empl+prior.yrs+educ+ gender+dept1.,data=technitron.df)
summary(tech.fit2)
tech.fit3<-lm(log(salary)~yrs.empl+educ+gender+dept1., data=technitron.df)
summary(tech.fit3)
plot(tech.fit3,which=1)
cooks20x(tech.fit3)
normcheck(tech.fit3)
exp(ciReg(tech.fit3,conf.level=0.9))

